@@ -9,11 +9,18 @@ subpackage (see :ref:`api-kernels`), and then passing that to a
 :ref:`tutorials` for a more complete introduction.
 """
 
-__all__ = ["kernels", "noise", "solvers", "transforms", "GaussianProcess"]
+__all__ = [
+    "__version__",
+    "kernels",
+    "noise",
+    "solvers",
+    "transforms",
+    "GaussianProcess",
+]
 
 from tinygp import kernels, noise, solvers, transforms
 from tinygp.gp import GaussianProcess
-from tinygp.tinygp_version import version as __version__
+from tinygp.tinygp_version import __version__
 
 __author__ = "Dan Foreman-Mackey"
 __email__ = "foreman.mackey@gmail.com"
